@@ -2,17 +2,16 @@
 ghreport.
 
 Usage:
-  ghreport <owner> <repo> <token> [-o FILE] [-v] [-d DAYS] [-a] [-s DAYS] [-u USERS] [-b LABEL] [-x DAYS] [-n NUM]
+  ghreport <repo> <token> [-o FILE] [-v] [-d DAYS] [-a] [-s DAYS] [-u USERS] [-b LABEL] [-x DAYS] [-n NUM]
   ghreport -h | --help
   ghreport --version
 
 Options:
-  <owner>                 The Github repository owner.
-  <repo>                  The Github repository name.
+  <repo>                  The Github repository (e.g. gramster/ghreport).
   <token>                 The Github API token used for authentication.
   -o FILE --out=FILE      Write output to specified file.
   -v --verbose            Show extra output like stats about GitHub API usage costs.
-  -d DAYS --days=DAYS     Window size (days) for items in report as new (with '*'). [default: 7]
+  -d DAYS --days=DAYS     Window size (days) for items in report as new (with '*'). [default: 1]
   -a --all                Show all relevant issues, not just those new in the window.
   -s DAYS --stale=DAYS    Window size (days) for marking issues with no 3rd party follow up as stale. [default: 30]
   -u USERS --users=USERS  Comma-separated list of extra users to consider as team members.
@@ -23,7 +22,8 @@ Options:
   --version               Show version.
 
 Output is plain text, unless -o is used and the file name ends in .html, 
-in which case HTML with an embedded bug count chart will be written to the file.
+in which case HTML with an embedded bug count chart will be written to the file,
+or if the file name ends in '.md', in which case Markdown will be used (no chart).
 The file name specified with -o will be formatted using strftime so you can
 add dynamic elements based on the current date.
 
@@ -31,16 +31,20 @@ You normally should not need to use the num argument unless you are experiencing
 timeouts from the GitHub API; in this case you may want to try a lower value.
 """
 
-__version__ = '0.4'
+__version__ = '0.6'
 
-from docopt import docopt
+from docopt import docopt, DocoptExit
 from .ghreport import report
 
 
 def main():
     arguments = docopt(__doc__, version=__version__)
-    owner = arguments['<owner>']
-    repo = arguments['<repo>']
+    components = arguments['<repo>'].split('/')
+    if len(components) == 2:
+        owner, repo = components
+    else:
+        raise DocoptExit()
+
     token = arguments['<token>']
     out = arguments['--out']
     verbose = arguments['--verbose']
